@@ -28,10 +28,10 @@ require DBI;    # for looks_like_number()
 
 BEGIN
 {
-    $VERSION = sprintf( "1.%06d", q$Revision: 14215 $ =~ /(\d+)/o );
+    $VERSION = sprintf( "1.%06d", q$Revision: 14495 $ =~ /(\d+)/o );
 
     $versions->{nano_version} = $VERSION;
-    if ( $ENV{DBI_SQL_NANO} || !eval { require SQL::Statement; $SQL::Statement::VERSION ge '1.27_02' } )
+    if ( $ENV{DBI_SQL_NANO} || !eval { require SQL::Statement; $SQL::Statement::VERSION ge '1.28' } )
     {
         @DBI::SQL::Nano::Statement::ISA = qw(DBI::SQL::Nano::Statement_);
         @DBI::SQL::Nano::Table::ISA     = qw(DBI::SQL::Nano::Table_);
@@ -110,7 +110,7 @@ sub prepare
                 $self->{where_clause} = $self->parse_where_clause($clauses) if ($clauses);
             }
         };
-        /^\s*INSERT\s+INTO\s+(\S+)\s*(\((.*?)\))?\s*VALUES\s*\((.+)\)/is
+        /^\s*INSERT\s+(?:INTO\s+)?(\S+)\s*(\((.*?)\))?\s*VALUES\s*\((.+)\)/is
           && do
         {
             $self->{command}      = 'INSERT';
@@ -309,7 +309,7 @@ sub DROP ($$$)
         return ( -1, 0 );
     }
 
-    $self->do_err( $@ || $err[0] ) if ( $@ || @err );
+    croak( $@ || $err[0] ) if ( $@ || @err );
     return ( -1, 0 ) unless $table;
 
     $table->drop($data);
